==> flink-connector-aws-4.3.0-src.tgz: flink-connector-aws-4.3.0/flink-connector-aws/flink-connector-aws-kinesis-streams/src/main/java/org/apache/flink/connector/kinesis/source/enumerator/KinesisStreamsSourceEnumeratorState.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.connector.kinesis.source.enumerator;

import org.apache.flink.annotation.Internal;
import org.apache.flink.connector.kinesis.source.split.KinesisShardSplit;

import javax.annotation.Nullable;

import java.util.Set;

/**
 * State for the {@link KinesisStreamsSourceEnumerator}. This class is stored in state, so any
 * changes need to be backwards compatible
 */
@Internal
public class KinesisStreamsSourceEnumeratorState {
    private final Set<KinesisShardSplit> unassignedSplits;
    @Nullable private final String lastSeenShardId;

    public KinesisStreamsSourceEnumeratorState(
            Set<KinesisShardSplit> unassignedSplits, String lastSeenShardId) {
        this.unassignedSplits = unassignedSplits;
        this.lastSeenShardId = lastSeenShardId;
    }

    public String getLastSeenShardId() {
        return lastSeenShardId;
    }

    public Set<KinesisShardSplit> getUnassignedSplits() {
        return unassignedSplits;
    }
}

==> flink-connector-aws-5.0.0-src.tgz: flink-connector-aws-5.0.0/flink-connector-aws/flink-connector-aws-kinesis-streams/src/main/java/org/apache/flink/connector/kinesis/source/enumerator/KinesisStreamsSourceEnumeratorState.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.connector.kinesis.source.enumerator;

import org.apache.flink.annotation.Internal;

import javax.annotation.Nullable;

import java.util.List;

/**
 * State for the {@link KinesisStreamsSourceEnumerator}. This class is stored in state, so any
 * changes need to be backwards compatible
 */
@Internal
public class KinesisStreamsSourceEnumeratorState {
    private final List<KinesisShardSplitWithAssignmentStatus> knownSplits;
    @Nullable private final String lastSeenShardId;

    public KinesisStreamsSourceEnumeratorState(
            List<KinesisShardSplitWithAssignmentStatus> knownSplits, String lastSeenShardId) {
        this.knownSplits = knownSplits;
        this.lastSeenShardId = lastSeenShardId;
    }

    public String getLastSeenShardId() {
        return lastSeenShardId;
    }

    public List<KinesisShardSplitWithAssignmentStatus> getKnownSplits() {
        return knownSplits;
    }
}
